Package: miniCRAN
Version: 0.3.2
Authors@R: c(
    person("Andrie", "de Vries", role=c("aut", "cre", "cph"), email="apdevries@gmail.com"),
    person("Alex", "Chubaty", role="ctb", email="alex.chubaty@gmail.com"),
    person("Microsoft Corporation", role="cph")
    )
License: GPL-2
Copyright: Andrie de Vries, Microsoft Corporation
Title: Create a Mini Version of CRAN Containing Only Selected Packages
Description: Makes it possible to create an internally consistent
    repository consisting of selected packages from CRAN-like repositories.
    The user specifies a set of desired packages, and 'miniCRAN' recursively
    reads the dependency tree for these packages, then downloads only this
    subset. The user can then install packages from this repository directly,
    rather than from CRAN.  This is useful in production settings, e.g. server
    behind a firewall, or remote locations with slow (or zero) Internet access.
URL: https://github.com/andrie/miniCRAN
BugReports: https://github.com/andrie/miniCRAN/issues
Imports: graphics, httr, methods, stats, tools, utils, igraph,
        assertthat (>= 0.2.0)
Suggests: devtools, knitr, rmarkdown, testthat (>= 2.1.0), covr, withr,
        mockery, testthis, roxygen2, mockr, spelling
LazyData: true
LazyLoad: true
VignetteBuilder: knitr
RoxygenNote: 7.3.1
Encoding: UTF-8
Language: en-US
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-16 09:24:45 UTC; apdev
Author: Andrie de Vries [aut, cre, cph],
  Alex Chubaty [ctb],
  Microsoft Corporation [cph]
Maintainer: Andrie de Vries <apdevries@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-16 10:00:03 UTC
Built: R 4.6.0; ; 2026-04-26 08:47:52 UTC; unix
