# Generated by roxygen2: do not edit by hand

S3method(plot,pkgDepGraph)
S3method(print,pkgDep)
export(addLocalPackage)
export(addOldPackage)
export(addPackage)
export(addPackageListingGithub)
export(basePkgs)
export(checkVersions)
export(getCranDescription)
export(is.online)
export(makeDepGraph)
export(makeLibrary)
export(makeRepo)
export(oldPackages)
export(pkgAvail)
export(pkgDep)
export(updatePackages)
export(updateRepoIndex)
importFrom(assertthat,"on_failure<-")
importFrom(assertthat,assert_that)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,title)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,stop_for_status)
importFrom(igraph,V)
importFrom(igraph,plot.igraph)
importFrom(methods,is)
importFrom(stats,reshape)
importFrom(stats,setNames)
importFrom(tools,write_PACKAGES)
importFrom(utils,chooseCRANmirror)
importFrom(utils,compareVersion)
importFrom(utils,download.file)
importFrom(utils,download.packages)
importFrom(utils,flush.console)
importFrom(utils,installed.packages)
importFrom(utils,select.list)
